[![PyPI version](https://badge.fury.io/py/pyprosegur.svg)](https://badge.fury.io/py/pyprosegur)

# PyProsegur
Python library to retrieve information from [Prosegur Residential Alarms](http://www.prosegur.pt)

## Requirements
- backoff
- aiohttp
- Click 

## Changelog

* 0.0.1 - Initial Release
* 0.0.4 - Support for MovistarProsegurAlarms
* 0.0.5 - Add exponential backoff retries
* 0.0.6 (unreleased) - Add last-event object
* 0.0.7 (unreleased) - Support for Colombia

## NOTES:

This project has no relationship with Prosegur (unofficial library).

The component uses the API provided by the Web Application.

Has been tested in Portugal, but should also work in other countries (please open an Issue and report your success!)

## LICENCE:
Code is under MIT licence.  
